#include <BF_Parameters.h>
#include <functions.h>

extern char CommandArray[5];
extern char SensorDataArray[5];
extern char SPITransferStatus;
extern char SPITransferCount;
extern char SensorRequest;			//0: Sensor request; 1: No sensor request
extern char N;
			
extern char COREorDMA;					//0: Core; 1: DMA
extern char ProcessData;				//0: Request for process data; 1: No request for process data

//--------------------------------------------------------------------------//
// Function:	IsrSPI														//
//																			//
// Parameters:	None														//
//																			//
// Return:		None														//
//																			//
// Description:	This ISR checks whether the interrupt is initiated by a 	//
//				Core/ DMA operation. For a Core operation, it sends the 	//
//				values that are pre-written into the Global command array.	//
//				It calls a function to disable SPI before return. 			//
//--------------------------------------------------------------------------//

EX_INTERRUPT_HANDLER (IsrSPI)
{   
    if(COREorDMA == 0)
    { 
	    SPITransferCount++;
	    *pSPI_TDBR = CommandArray[SPITransferCount];
	    SensorDataArray[SPITransferCount] = *pSPI_RDBR;
    
	    if(SPITransferCount == N)
	    {
	        SPITransferStatus = 0;
	        DisableSlowSPI();
	    }    
    }
    else
    {
        *pDMA5_IRQ_STATUS |= 0x0001;
        ProcessData = 0;
        DisableFastSPI();
        COREorDMA = 0;
    }
}

//--------------------------------------------------------------------------//
// Function:	IsrIRQ														//
//																			//
// Parameters:	None														//
//																			//
// Return:		None														//
//																			//
// Description:	This ISR executes when the IRQ signal of the sensor is 		//
//				driven Low. It clears a flag to indicate Sensor Request.	//
//--------------------------------------------------------------------------//

EX_INTERRUPT_HANDLER (IsrIRQ)
{
    SensorRequest = 0;
    ssync();
    *pFIO_FLAG_C = 0x10;
    
}

